@@ -184,15 +184,15 @@ class ComprehendClient:
         self,
         DocumentClassifierName: str,
         DataAccessRoleArn: str,
-        InputDataConfig: DocumentClassifierInputDataConfigTypeDef,
+        InputDataConfig: "DocumentClassifierInputDataConfigTypeDef",
         LanguageCode: Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
         ],
-        Tags: List[TagTypeDef] = None,
-        OutputDataConfig: DocumentClassifierOutputDataConfigTypeDef = None,
+        Tags: List["TagTypeDef"] = None,
+        OutputDataConfig: "DocumentClassifierOutputDataConfigTypeDef" = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
         Mode: Literal["MULTI_CLASS", "MULTI_LABEL"] = None,
     ) -> CreateDocumentClassifierResponseTypeDef:
         """
@@ -205,7 +205,7 @@ class ComprehendClient:
         ModelArn: str,
         DesiredInferenceUnits: int,
         ClientRequestToken: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateEndpointResponseTypeDef:
         """
         [Client.create_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
@@ -215,14 +215,14 @@ class ComprehendClient:
         self,
         RecognizerName: str,
         DataAccessRoleArn: str,
-        InputDataConfig: EntityRecognizerInputDataConfigTypeDef,
+        InputDataConfig: "EntityRecognizerInputDataConfigTypeDef",
         LanguageCode: Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
         ],
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> CreateEntityRecognizerResponseTypeDef:
         """
         [Client.create_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.create_entity_recognizer)
@@ -455,13 +455,13 @@ class ComprehendClient:
     def start_document_classification_job(
         self,
         DocumentClassifierArn: str,
-        InputDataConfig: InputDataConfigTypeDef,
-        OutputDataConfig: OutputDataConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
         JobName: str = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartDocumentClassificationJobResponseTypeDef:
         """
         [Client.start_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.start_document_classification_job)
@@ -469,13 +469,13 @@ class ComprehendClient:
 
     def start_dominant_language_detection_job(
         self,
-        InputDataConfig: InputDataConfigTypeDef,
-        OutputDataConfig: OutputDataConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
         JobName: str = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartDominantLanguageDetectionJobResponseTypeDef:
         """
         [Client.start_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.start_dominant_language_detection_job)
@@ -483,8 +483,8 @@ class ComprehendClient:
 
     def start_entities_detection_job(
         self,
-        InputDataConfig: InputDataConfigTypeDef,
-        OutputDataConfig: OutputDataConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
         LanguageCode: Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
@@ -493,7 +493,7 @@ class ComprehendClient:
         EntityRecognizerArn: str = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartEntitiesDetectionJobResponseTypeDef:
         """
         [Client.start_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.start_entities_detection_job)
@@ -501,8 +501,8 @@ class ComprehendClient:
 
     def start_key_phrases_detection_job(
         self,
-        InputDataConfig: InputDataConfigTypeDef,
-        OutputDataConfig: OutputDataConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
         LanguageCode: Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
@@ -510,7 +510,7 @@ class ComprehendClient:
         JobName: str = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartKeyPhrasesDetectionJobResponseTypeDef:
         """
         [Client.start_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.start_key_phrases_detection_job)
@@ -518,8 +518,8 @@ class ComprehendClient:
 
     def start_sentiment_detection_job(
         self,
-        InputDataConfig: InputDataConfigTypeDef,
-        OutputDataConfig: OutputDataConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
         LanguageCode: Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
@@ -527,7 +527,7 @@ class ComprehendClient:
         JobName: str = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartSentimentDetectionJobResponseTypeDef:
         """
         [Client.start_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.start_sentiment_detection_job)
@@ -535,14 +535,14 @@ class ComprehendClient:
 
     def start_topics_detection_job(
         self,
-        InputDataConfig: InputDataConfigTypeDef,
-        OutputDataConfig: OutputDataConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
         JobName: str = None,
         NumberOfTopics: int = None,
         ClientRequestToken: str = None,
         VolumeKmsKeyId: str = None,
-        VpcConfig: VpcConfigTypeDef = None,
+        VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartTopicsDetectionJobResponseTypeDef:
         """
         [Client.start_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.start_topics_detection_job)
@@ -582,7 +582,7 @@ class ComprehendClient:
         [Client.stop_training_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.stop_training_entity_recognizer)
         """
 
-    def tag_resource(self, ResourceArn: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
+    def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Client.tag_resource)
         """
