@@ -3,9 +3,9 @@ Main interface for comprehend service type definitions.
 
 Usage::
 
-    from mypy_boto3.comprehend.type_defs import DominantLanguageTypeDef
+    from mypy_boto3.comprehend.type_defs import BatchDetectDominantLanguageItemResultTypeDef
 
-    data: DominantLanguageTypeDef = {...}
+    data: BatchDetectDominantLanguageItemResultTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,62 +22,63 @@ else:
 
 
 __all__ = (
-    "DominantLanguageTypeDef",
     "BatchDetectDominantLanguageItemResultTypeDef",
-    "BatchItemErrorTypeDef",
-    "BatchDetectDominantLanguageResponseTypeDef",
-    "EntityTypeDef",
     "BatchDetectEntitiesItemResultTypeDef",
-    "BatchDetectEntitiesResponseTypeDef",
-    "KeyPhraseTypeDef",
     "BatchDetectKeyPhrasesItemResultTypeDef",
-    "BatchDetectKeyPhrasesResponseTypeDef",
-    "SentimentScoreTypeDef",
     "BatchDetectSentimentItemResultTypeDef",
-    "BatchDetectSentimentResponseTypeDef",
-    "PartOfSpeechTagTypeDef",
-    "SyntaxTokenTypeDef",
     "BatchDetectSyntaxItemResultTypeDef",
-    "BatchDetectSyntaxResponseTypeDef",
+    "BatchItemErrorTypeDef",
+    "ClassifierEvaluationMetricsTypeDef",
+    "ClassifierMetadataTypeDef",
     "DocumentClassTypeDef",
+    "DocumentClassificationJobPropertiesTypeDef",
+    "DocumentClassifierInputDataConfigTypeDef",
+    "DocumentClassifierOutputDataConfigTypeDef",
+    "DocumentClassifierPropertiesTypeDef",
     "DocumentLabelTypeDef",
+    "DominantLanguageDetectionJobPropertiesTypeDef",
+    "DominantLanguageTypeDef",
+    "EndpointPropertiesTypeDef",
+    "EntitiesDetectionJobPropertiesTypeDef",
+    "EntityRecognizerAnnotationsTypeDef",
+    "EntityRecognizerDocumentsTypeDef",
+    "EntityRecognizerEntityListTypeDef",
+    "EntityRecognizerEvaluationMetricsTypeDef",
+    "EntityRecognizerInputDataConfigTypeDef",
+    "EntityRecognizerMetadataEntityTypesListItemTypeDef",
+    "EntityRecognizerMetadataTypeDef",
+    "EntityRecognizerPropertiesTypeDef",
+    "EntityTypeDef",
+    "EntityTypesEvaluationMetricsTypeDef",
+    "EntityTypesListItemTypeDef",
+    "InputDataConfigTypeDef",
+    "KeyPhraseTypeDef",
+    "KeyPhrasesDetectionJobPropertiesTypeDef",
+    "OutputDataConfigTypeDef",
+    "PartOfSpeechTagTypeDef",
+    "SentimentDetectionJobPropertiesTypeDef",
+    "SentimentScoreTypeDef",
+    "SyntaxTokenTypeDef",
+    "TagTypeDef",
+    "TopicsDetectionJobPropertiesTypeDef",
+    "VpcConfigTypeDef",
+    "BatchDetectDominantLanguageResponseTypeDef",
+    "BatchDetectEntitiesResponseTypeDef",
+    "BatchDetectKeyPhrasesResponseTypeDef",
+    "BatchDetectSentimentResponseTypeDef",
+    "BatchDetectSyntaxResponseTypeDef",
     "ClassifyDocumentResponseTypeDef",
     "CreateDocumentClassifierResponseTypeDef",
     "CreateEndpointResponseTypeDef",
     "CreateEntityRecognizerResponseTypeDef",
-    "InputDataConfigTypeDef",
-    "OutputDataConfigTypeDef",
-    "VpcConfigTypeDef",
-    "DocumentClassificationJobPropertiesTypeDef",
     "DescribeDocumentClassificationJobResponseTypeDef",
-    "ClassifierEvaluationMetricsTypeDef",
-    "ClassifierMetadataTypeDef",
-    "DocumentClassifierInputDataConfigTypeDef",
-    "DocumentClassifierOutputDataConfigTypeDef",
-    "DocumentClassifierPropertiesTypeDef",
     "DescribeDocumentClassifierResponseTypeDef",
-    "DominantLanguageDetectionJobPropertiesTypeDef",
     "DescribeDominantLanguageDetectionJobResponseTypeDef",
-    "EndpointPropertiesTypeDef",
     "DescribeEndpointResponseTypeDef",
-    "EntitiesDetectionJobPropertiesTypeDef",
     "DescribeEntitiesDetectionJobResponseTypeDef",
-    "EntityRecognizerAnnotationsTypeDef",
-    "EntityRecognizerDocumentsTypeDef",
-    "EntityRecognizerEntityListTypeDef",
-    "EntityTypesListItemTypeDef",
-    "EntityRecognizerInputDataConfigTypeDef",
-    "EntityRecognizerEvaluationMetricsTypeDef",
-    "EntityTypesEvaluationMetricsTypeDef",
-    "EntityRecognizerMetadataEntityTypesListItemTypeDef",
-    "EntityRecognizerMetadataTypeDef",
-    "EntityRecognizerPropertiesTypeDef",
     "DescribeEntityRecognizerResponseTypeDef",
-    "KeyPhrasesDetectionJobPropertiesTypeDef",
     "DescribeKeyPhrasesDetectionJobResponseTypeDef",
-    "SentimentDetectionJobPropertiesTypeDef",
     "DescribeSentimentDetectionJobResponseTypeDef",
-    "TopicsDetectionJobPropertiesTypeDef",
     "DescribeTopicsDetectionJobResponseTypeDef",
     "DetectDominantLanguageResponseTypeDef",
     "DetectEntitiesResponseTypeDef",
@@ -99,7 +100,6 @@ __all__ = (
     "ListEntityRecognizersResponseTypeDef",
     "ListKeyPhrasesDetectionJobsResponseTypeDef",
     "ListSentimentDetectionJobsResponseTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListTopicsDetectionJobsResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -117,87 +117,21 @@ __all__ = (
     "TopicsDetectionJobFilterTypeDef",
 )
 
-DominantLanguageTypeDef = TypedDict(
-    "DominantLanguageTypeDef", {"LanguageCode": str, "Score": float}, total=False
-)
-
 BatchDetectDominantLanguageItemResultTypeDef = TypedDict(
     "BatchDetectDominantLanguageItemResultTypeDef",
-    {"Index": int, "Languages": List[DominantLanguageTypeDef]},
-    total=False,
-)
-
-BatchItemErrorTypeDef = TypedDict(
-    "BatchItemErrorTypeDef", {"Index": int, "ErrorCode": str, "ErrorMessage": str}, total=False
-)
-
-BatchDetectDominantLanguageResponseTypeDef = TypedDict(
-    "BatchDetectDominantLanguageResponseTypeDef",
-    {
-        "ResultList": List[BatchDetectDominantLanguageItemResultTypeDef],
-        "ErrorList": List[BatchItemErrorTypeDef],
-    },
-)
-
-EntityTypeDef = TypedDict(
-    "EntityTypeDef",
-    {
-        "Score": float,
-        "Type": Literal[
-            "PERSON",
-            "LOCATION",
-            "ORGANIZATION",
-            "COMMERCIAL_ITEM",
-            "EVENT",
-            "DATE",
-            "QUANTITY",
-            "TITLE",
-            "OTHER",
-        ],
-        "Text": str,
-        "BeginOffset": int,
-        "EndOffset": int,
-    },
+    {"Index": int, "Languages": List["DominantLanguageTypeDef"]},
     total=False,
 )
 
 BatchDetectEntitiesItemResultTypeDef = TypedDict(
     "BatchDetectEntitiesItemResultTypeDef",
-    {"Index": int, "Entities": List[EntityTypeDef]},
-    total=False,
-)
-
-BatchDetectEntitiesResponseTypeDef = TypedDict(
-    "BatchDetectEntitiesResponseTypeDef",
-    {
-        "ResultList": List[BatchDetectEntitiesItemResultTypeDef],
-        "ErrorList": List[BatchItemErrorTypeDef],
-    },
-)
-
-KeyPhraseTypeDef = TypedDict(
-    "KeyPhraseTypeDef",
-    {"Score": float, "Text": str, "BeginOffset": int, "EndOffset": int},
+    {"Index": int, "Entities": List["EntityTypeDef"]},
     total=False,
 )
 
 BatchDetectKeyPhrasesItemResultTypeDef = TypedDict(
     "BatchDetectKeyPhrasesItemResultTypeDef",
-    {"Index": int, "KeyPhrases": List[KeyPhraseTypeDef]},
-    total=False,
-)
-
-BatchDetectKeyPhrasesResponseTypeDef = TypedDict(
-    "BatchDetectKeyPhrasesResponseTypeDef",
-    {
-        "ResultList": List[BatchDetectKeyPhrasesItemResultTypeDef],
-        "ErrorList": List[BatchItemErrorTypeDef],
-    },
-)
-
-SentimentScoreTypeDef = TypedDict(
-    "SentimentScoreTypeDef",
-    {"Positive": float, "Negative": float, "Neutral": float, "Mixed": float},
+    {"Index": int, "KeyPhrases": List["KeyPhraseTypeDef"]},
     total=False,
 )
 
@@ -206,146 +140,19 @@ BatchDetectSentimentItemResultTypeDef = TypedDict(
     {
         "Index": int,
         "Sentiment": Literal["POSITIVE", "NEGATIVE", "NEUTRAL", "MIXED"],
-        "SentimentScore": SentimentScoreTypeDef,
-    },
-    total=False,
-)
-
-BatchDetectSentimentResponseTypeDef = TypedDict(
-    "BatchDetectSentimentResponseTypeDef",
-    {
-        "ResultList": List[BatchDetectSentimentItemResultTypeDef],
-        "ErrorList": List[BatchItemErrorTypeDef],
-    },
-)
-
-PartOfSpeechTagTypeDef = TypedDict(
-    "PartOfSpeechTagTypeDef",
-    {
-        "Tag": Literal[
-            "ADJ",
-            "ADP",
-            "ADV",
-            "AUX",
-            "CONJ",
-            "CCONJ",
-            "DET",
-            "INTJ",
-            "NOUN",
-            "NUM",
-            "O",
-            "PART",
-            "PRON",
-            "PROPN",
-            "PUNCT",
-            "SCONJ",
-            "SYM",
-            "VERB",
-        ],
-        "Score": float,
-    },
-    total=False,
-)
-
-SyntaxTokenTypeDef = TypedDict(
-    "SyntaxTokenTypeDef",
-    {
-        "TokenId": int,
-        "Text": str,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "PartOfSpeech": PartOfSpeechTagTypeDef,
+        "SentimentScore": "SentimentScoreTypeDef",
     },
     total=False,
 )
 
 BatchDetectSyntaxItemResultTypeDef = TypedDict(
     "BatchDetectSyntaxItemResultTypeDef",
-    {"Index": int, "SyntaxTokens": List[SyntaxTokenTypeDef]},
+    {"Index": int, "SyntaxTokens": List["SyntaxTokenTypeDef"]},
     total=False,
 )
 
-BatchDetectSyntaxResponseTypeDef = TypedDict(
-    "BatchDetectSyntaxResponseTypeDef",
-    {
-        "ResultList": List[BatchDetectSyntaxItemResultTypeDef],
-        "ErrorList": List[BatchItemErrorTypeDef],
-    },
-)
-
-DocumentClassTypeDef = TypedDict("DocumentClassTypeDef", {"Name": str, "Score": float}, total=False)
-
-DocumentLabelTypeDef = TypedDict("DocumentLabelTypeDef", {"Name": str, "Score": float}, total=False)
-
-ClassifyDocumentResponseTypeDef = TypedDict(
-    "ClassifyDocumentResponseTypeDef",
-    {"Classes": List[DocumentClassTypeDef], "Labels": List[DocumentLabelTypeDef]},
-    total=False,
-)
-
-CreateDocumentClassifierResponseTypeDef = TypedDict(
-    "CreateDocumentClassifierResponseTypeDef", {"DocumentClassifierArn": str}, total=False
-)
-
-CreateEndpointResponseTypeDef = TypedDict(
-    "CreateEndpointResponseTypeDef", {"EndpointArn": str}, total=False
-)
-
-CreateEntityRecognizerResponseTypeDef = TypedDict(
-    "CreateEntityRecognizerResponseTypeDef", {"EntityRecognizerArn": str}, total=False
-)
-
-_RequiredInputDataConfigTypeDef = TypedDict("_RequiredInputDataConfigTypeDef", {"S3Uri": str})
-_OptionalInputDataConfigTypeDef = TypedDict(
-    "_OptionalInputDataConfigTypeDef",
-    {"InputFormat": Literal["ONE_DOC_PER_FILE", "ONE_DOC_PER_LINE"]},
-    total=False,
-)
-
-
-class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
-    pass
-
-
-_RequiredOutputDataConfigTypeDef = TypedDict("_RequiredOutputDataConfigTypeDef", {"S3Uri": str})
-_OptionalOutputDataConfigTypeDef = TypedDict(
-    "_OptionalOutputDataConfigTypeDef", {"KmsKeyId": str}, total=False
-)
-
-
-class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputDataConfigTypeDef):
-    pass
-
-
-VpcConfigTypeDef = TypedDict(
-    "VpcConfigTypeDef", {"SecurityGroupIds": List[str], "Subnets": List[str]}
-)
-
-DocumentClassificationJobPropertiesTypeDef = TypedDict(
-    "DocumentClassificationJobPropertiesTypeDef",
-    {
-        "JobId": str,
-        "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-        "Message": str,
-        "SubmitTime": datetime,
-        "EndTime": datetime,
-        "DocumentClassifierArn": str,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
-        "DataAccessRoleArn": str,
-        "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
-    },
-    total=False,
-)
-
-DescribeDocumentClassificationJobResponseTypeDef = TypedDict(
-    "DescribeDocumentClassificationJobResponseTypeDef",
-    {"DocumentClassificationJobProperties": DocumentClassificationJobPropertiesTypeDef},
-    total=False,
+BatchItemErrorTypeDef = TypedDict(
+    "BatchItemErrorTypeDef", {"Index": int, "ErrorCode": str, "ErrorMessage": str}, total=False
 )
 
 ClassifierEvaluationMetricsTypeDef = TypedDict(
@@ -369,7 +176,30 @@ ClassifierMetadataTypeDef = TypedDict(
         "NumberOfLabels": int,
         "NumberOfTrainedDocuments": int,
         "NumberOfTestDocuments": int,
-        "EvaluationMetrics": ClassifierEvaluationMetricsTypeDef,
+        "EvaluationMetrics": "ClassifierEvaluationMetricsTypeDef",
+    },
+    total=False,
+)
+
+DocumentClassTypeDef = TypedDict("DocumentClassTypeDef", {"Name": str, "Score": float}, total=False)
+
+DocumentClassificationJobPropertiesTypeDef = TypedDict(
+    "DocumentClassificationJobPropertiesTypeDef",
+    {
+        "JobId": str,
+        "JobName": str,
+        "JobStatus": Literal[
+            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
+        ],
+        "Message": str,
+        "SubmitTime": datetime,
+        "EndTime": datetime,
+        "DocumentClassifierArn": str,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "VolumeKmsKeyId": str,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
@@ -408,22 +238,18 @@ DocumentClassifierPropertiesTypeDef = TypedDict(
         "EndTime": datetime,
         "TrainingStartTime": datetime,
         "TrainingEndTime": datetime,
-        "InputDataConfig": DocumentClassifierInputDataConfigTypeDef,
-        "OutputDataConfig": DocumentClassifierOutputDataConfigTypeDef,
-        "ClassifierMetadata": ClassifierMetadataTypeDef,
+        "InputDataConfig": "DocumentClassifierInputDataConfigTypeDef",
+        "OutputDataConfig": "DocumentClassifierOutputDataConfigTypeDef",
+        "ClassifierMetadata": "ClassifierMetadataTypeDef",
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
         "Mode": Literal["MULTI_CLASS", "MULTI_LABEL"],
     },
     total=False,
 )
 
-DescribeDocumentClassifierResponseTypeDef = TypedDict(
-    "DescribeDocumentClassifierResponseTypeDef",
-    {"DocumentClassifierProperties": DocumentClassifierPropertiesTypeDef},
-    total=False,
-)
+DocumentLabelTypeDef = TypedDict("DocumentLabelTypeDef", {"Name": str, "Score": float}, total=False)
 
 DominantLanguageDetectionJobPropertiesTypeDef = TypedDict(
     "DominantLanguageDetectionJobPropertiesTypeDef",
@@ -436,19 +262,17 @@ DominantLanguageDetectionJobPropertiesTypeDef = TypedDict(
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
 
-DescribeDominantLanguageDetectionJobResponseTypeDef = TypedDict(
-    "DescribeDominantLanguageDetectionJobResponseTypeDef",
-    {"DominantLanguageDetectionJobProperties": DominantLanguageDetectionJobPropertiesTypeDef},
-    total=False,
+DominantLanguageTypeDef = TypedDict(
+    "DominantLanguageTypeDef", {"LanguageCode": str, "Score": float}, total=False
 )
 
 EndpointPropertiesTypeDef = TypedDict(
@@ -466,12 +290,6 @@ EndpointPropertiesTypeDef = TypedDict(
     total=False,
 )
 
-DescribeEndpointResponseTypeDef = TypedDict(
-    "DescribeEndpointResponseTypeDef",
-    {"EndpointProperties": EndpointPropertiesTypeDef},
-    total=False,
-)
-
 EntitiesDetectionJobPropertiesTypeDef = TypedDict(
     "EntitiesDetectionJobPropertiesTypeDef",
     {
@@ -484,44 +302,42 @@ EntitiesDetectionJobPropertiesTypeDef = TypedDict(
         "SubmitTime": datetime,
         "EndTime": datetime,
         "EntityRecognizerArn": str,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
         "LanguageCode": Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
         ],
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
 
-DescribeEntitiesDetectionJobResponseTypeDef = TypedDict(
-    "DescribeEntitiesDetectionJobResponseTypeDef",
-    {"EntitiesDetectionJobProperties": EntitiesDetectionJobPropertiesTypeDef},
-    total=False,
-)
-
 EntityRecognizerAnnotationsTypeDef = TypedDict("EntityRecognizerAnnotationsTypeDef", {"S3Uri": str})
 
 EntityRecognizerDocumentsTypeDef = TypedDict("EntityRecognizerDocumentsTypeDef", {"S3Uri": str})
 
 EntityRecognizerEntityListTypeDef = TypedDict("EntityRecognizerEntityListTypeDef", {"S3Uri": str})
 
-EntityTypesListItemTypeDef = TypedDict("EntityTypesListItemTypeDef", {"Type": str})
+EntityRecognizerEvaluationMetricsTypeDef = TypedDict(
+    "EntityRecognizerEvaluationMetricsTypeDef",
+    {"Precision": float, "Recall": float, "F1Score": float},
+    total=False,
+)
 
 _RequiredEntityRecognizerInputDataConfigTypeDef = TypedDict(
     "_RequiredEntityRecognizerInputDataConfigTypeDef",
     {
-        "EntityTypes": List[EntityTypesListItemTypeDef],
-        "Documents": EntityRecognizerDocumentsTypeDef,
+        "EntityTypes": List["EntityTypesListItemTypeDef"],
+        "Documents": "EntityRecognizerDocumentsTypeDef",
     },
 )
 _OptionalEntityRecognizerInputDataConfigTypeDef = TypedDict(
     "_OptionalEntityRecognizerInputDataConfigTypeDef",
     {
-        "Annotations": EntityRecognizerAnnotationsTypeDef,
-        "EntityList": EntityRecognizerEntityListTypeDef,
+        "Annotations": "EntityRecognizerAnnotationsTypeDef",
+        "EntityList": "EntityRecognizerEntityListTypeDef",
     },
     total=False,
 )
@@ -533,23 +349,11 @@ class EntityRecognizerInputDataConfigTypeDef(
     pass
 
 
-EntityRecognizerEvaluationMetricsTypeDef = TypedDict(
-    "EntityRecognizerEvaluationMetricsTypeDef",
-    {"Precision": float, "Recall": float, "F1Score": float},
-    total=False,
-)
-
-EntityTypesEvaluationMetricsTypeDef = TypedDict(
-    "EntityTypesEvaluationMetricsTypeDef",
-    {"Precision": float, "Recall": float, "F1Score": float},
-    total=False,
-)
-
 EntityRecognizerMetadataEntityTypesListItemTypeDef = TypedDict(
     "EntityRecognizerMetadataEntityTypesListItemTypeDef",
     {
         "Type": str,
-        "EvaluationMetrics": EntityTypesEvaluationMetricsTypeDef,
+        "EvaluationMetrics": "EntityTypesEvaluationMetricsTypeDef",
         "NumberOfTrainMentions": int,
     },
     total=False,
@@ -560,8 +364,8 @@ EntityRecognizerMetadataTypeDef = TypedDict(
     {
         "NumberOfTrainedDocuments": int,
         "NumberOfTestDocuments": int,
-        "EvaluationMetrics": EntityRecognizerEvaluationMetricsTypeDef,
-        "EntityTypes": List[EntityRecognizerMetadataEntityTypesListItemTypeDef],
+        "EvaluationMetrics": "EntityRecognizerEvaluationMetricsTypeDef",
+        "EntityTypes": List["EntityRecognizerMetadataEntityTypesListItemTypeDef"],
     },
     total=False,
 )
@@ -581,18 +385,60 @@ EntityRecognizerPropertiesTypeDef = TypedDict(
         "EndTime": datetime,
         "TrainingStartTime": datetime,
         "TrainingEndTime": datetime,
-        "InputDataConfig": EntityRecognizerInputDataConfigTypeDef,
-        "RecognizerMetadata": EntityRecognizerMetadataTypeDef,
+        "InputDataConfig": "EntityRecognizerInputDataConfigTypeDef",
+        "RecognizerMetadata": "EntityRecognizerMetadataTypeDef",
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
 
-DescribeEntityRecognizerResponseTypeDef = TypedDict(
-    "DescribeEntityRecognizerResponseTypeDef",
-    {"EntityRecognizerProperties": EntityRecognizerPropertiesTypeDef},
+EntityTypeDef = TypedDict(
+    "EntityTypeDef",
+    {
+        "Score": float,
+        "Type": Literal[
+            "PERSON",
+            "LOCATION",
+            "ORGANIZATION",
+            "COMMERCIAL_ITEM",
+            "EVENT",
+            "DATE",
+            "QUANTITY",
+            "TITLE",
+            "OTHER",
+        ],
+        "Text": str,
+        "BeginOffset": int,
+        "EndOffset": int,
+    },
+    total=False,
+)
+
+EntityTypesEvaluationMetricsTypeDef = TypedDict(
+    "EntityTypesEvaluationMetricsTypeDef",
+    {"Precision": float, "Recall": float, "F1Score": float},
+    total=False,
+)
+
+EntityTypesListItemTypeDef = TypedDict("EntityTypesListItemTypeDef", {"Type": str})
+
+_RequiredInputDataConfigTypeDef = TypedDict("_RequiredInputDataConfigTypeDef", {"S3Uri": str})
+_OptionalInputDataConfigTypeDef = TypedDict(
+    "_OptionalInputDataConfigTypeDef",
+    {"InputFormat": Literal["ONE_DOC_PER_FILE", "ONE_DOC_PER_LINE"]},
+    total=False,
+)
+
+
+class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
+    pass
+
+
+KeyPhraseTypeDef = TypedDict(
+    "KeyPhraseTypeDef",
+    {"Score": float, "Text": str, "BeginOffset": int, "EndOffset": int},
     total=False,
 )
 
@@ -607,21 +453,53 @@ KeyPhrasesDetectionJobPropertiesTypeDef = TypedDict(
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
         "LanguageCode": Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
         ],
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
 
-DescribeKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
-    "DescribeKeyPhrasesDetectionJobResponseTypeDef",
-    {"KeyPhrasesDetectionJobProperties": KeyPhrasesDetectionJobPropertiesTypeDef},
+_RequiredOutputDataConfigTypeDef = TypedDict("_RequiredOutputDataConfigTypeDef", {"S3Uri": str})
+_OptionalOutputDataConfigTypeDef = TypedDict(
+    "_OptionalOutputDataConfigTypeDef", {"KmsKeyId": str}, total=False
+)
+
+
+class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputDataConfigTypeDef):
+    pass
+
+
+PartOfSpeechTagTypeDef = TypedDict(
+    "PartOfSpeechTagTypeDef",
+    {
+        "Tag": Literal[
+            "ADJ",
+            "ADP",
+            "ADV",
+            "AUX",
+            "CONJ",
+            "CCONJ",
+            "DET",
+            "INTJ",
+            "NOUN",
+            "NUM",
+            "O",
+            "PART",
+            "PRON",
+            "PROPN",
+            "PUNCT",
+            "SCONJ",
+            "SYM",
+            "VERB",
+        ],
+        "Score": float,
+    },
     total=False,
 )
 
@@ -636,24 +514,44 @@ SentimentDetectionJobPropertiesTypeDef = TypedDict(
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
         "LanguageCode": Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
         ],
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
 
-DescribeSentimentDetectionJobResponseTypeDef = TypedDict(
-    "DescribeSentimentDetectionJobResponseTypeDef",
-    {"SentimentDetectionJobProperties": SentimentDetectionJobPropertiesTypeDef},
+SentimentScoreTypeDef = TypedDict(
+    "SentimentScoreTypeDef",
+    {"Positive": float, "Negative": float, "Neutral": float, "Mixed": float},
     total=False,
 )
 
+SyntaxTokenTypeDef = TypedDict(
+    "SyntaxTokenTypeDef",
+    {
+        "TokenId": int,
+        "Text": str,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "PartOfSpeech": "PartOfSpeechTagTypeDef",
+    },
+    total=False,
+)
+
+_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
+_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"Value": str}, total=False)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
+
 TopicsDetectionJobPropertiesTypeDef = TypedDict(
     "TopicsDetectionJobPropertiesTypeDef",
     {
@@ -665,47 +563,157 @@ TopicsDetectionJobPropertiesTypeDef = TypedDict(
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
         "NumberOfTopics": int,
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
-        "VpcConfig": VpcConfigTypeDef,
+        "VpcConfig": "VpcConfigTypeDef",
     },
     total=False,
 )
 
+VpcConfigTypeDef = TypedDict(
+    "VpcConfigTypeDef", {"SecurityGroupIds": List[str], "Subnets": List[str]}
+)
+
+BatchDetectDominantLanguageResponseTypeDef = TypedDict(
+    "BatchDetectDominantLanguageResponseTypeDef",
+    {
+        "ResultList": List["BatchDetectDominantLanguageItemResultTypeDef"],
+        "ErrorList": List["BatchItemErrorTypeDef"],
+    },
+)
+
+BatchDetectEntitiesResponseTypeDef = TypedDict(
+    "BatchDetectEntitiesResponseTypeDef",
+    {
+        "ResultList": List["BatchDetectEntitiesItemResultTypeDef"],
+        "ErrorList": List["BatchItemErrorTypeDef"],
+    },
+)
+
+BatchDetectKeyPhrasesResponseTypeDef = TypedDict(
+    "BatchDetectKeyPhrasesResponseTypeDef",
+    {
+        "ResultList": List["BatchDetectKeyPhrasesItemResultTypeDef"],
+        "ErrorList": List["BatchItemErrorTypeDef"],
+    },
+)
+
+BatchDetectSentimentResponseTypeDef = TypedDict(
+    "BatchDetectSentimentResponseTypeDef",
+    {
+        "ResultList": List["BatchDetectSentimentItemResultTypeDef"],
+        "ErrorList": List["BatchItemErrorTypeDef"],
+    },
+)
+
+BatchDetectSyntaxResponseTypeDef = TypedDict(
+    "BatchDetectSyntaxResponseTypeDef",
+    {
+        "ResultList": List["BatchDetectSyntaxItemResultTypeDef"],
+        "ErrorList": List["BatchItemErrorTypeDef"],
+    },
+)
+
+ClassifyDocumentResponseTypeDef = TypedDict(
+    "ClassifyDocumentResponseTypeDef",
+    {"Classes": List["DocumentClassTypeDef"], "Labels": List["DocumentLabelTypeDef"]},
+    total=False,
+)
+
+CreateDocumentClassifierResponseTypeDef = TypedDict(
+    "CreateDocumentClassifierResponseTypeDef", {"DocumentClassifierArn": str}, total=False
+)
+
+CreateEndpointResponseTypeDef = TypedDict(
+    "CreateEndpointResponseTypeDef", {"EndpointArn": str}, total=False
+)
+
+CreateEntityRecognizerResponseTypeDef = TypedDict(
+    "CreateEntityRecognizerResponseTypeDef", {"EntityRecognizerArn": str}, total=False
+)
+
+DescribeDocumentClassificationJobResponseTypeDef = TypedDict(
+    "DescribeDocumentClassificationJobResponseTypeDef",
+    {"DocumentClassificationJobProperties": "DocumentClassificationJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeDocumentClassifierResponseTypeDef = TypedDict(
+    "DescribeDocumentClassifierResponseTypeDef",
+    {"DocumentClassifierProperties": "DocumentClassifierPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeDominantLanguageDetectionJobResponseTypeDef = TypedDict(
+    "DescribeDominantLanguageDetectionJobResponseTypeDef",
+    {"DominantLanguageDetectionJobProperties": "DominantLanguageDetectionJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeEndpointResponseTypeDef = TypedDict(
+    "DescribeEndpointResponseTypeDef",
+    {"EndpointProperties": "EndpointPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeEntitiesDetectionJobResponseTypeDef = TypedDict(
+    "DescribeEntitiesDetectionJobResponseTypeDef",
+    {"EntitiesDetectionJobProperties": "EntitiesDetectionJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeEntityRecognizerResponseTypeDef = TypedDict(
+    "DescribeEntityRecognizerResponseTypeDef",
+    {"EntityRecognizerProperties": "EntityRecognizerPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
+    "DescribeKeyPhrasesDetectionJobResponseTypeDef",
+    {"KeyPhrasesDetectionJobProperties": "KeyPhrasesDetectionJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeSentimentDetectionJobResponseTypeDef = TypedDict(
+    "DescribeSentimentDetectionJobResponseTypeDef",
+    {"SentimentDetectionJobProperties": "SentimentDetectionJobPropertiesTypeDef"},
+    total=False,
+)
+
 DescribeTopicsDetectionJobResponseTypeDef = TypedDict(
     "DescribeTopicsDetectionJobResponseTypeDef",
-    {"TopicsDetectionJobProperties": TopicsDetectionJobPropertiesTypeDef},
+    {"TopicsDetectionJobProperties": "TopicsDetectionJobPropertiesTypeDef"},
     total=False,
 )
 
 DetectDominantLanguageResponseTypeDef = TypedDict(
     "DetectDominantLanguageResponseTypeDef",
-    {"Languages": List[DominantLanguageTypeDef]},
+    {"Languages": List["DominantLanguageTypeDef"]},
     total=False,
 )
 
 DetectEntitiesResponseTypeDef = TypedDict(
-    "DetectEntitiesResponseTypeDef", {"Entities": List[EntityTypeDef]}, total=False
+    "DetectEntitiesResponseTypeDef", {"Entities": List["EntityTypeDef"]}, total=False
 )
 
 DetectKeyPhrasesResponseTypeDef = TypedDict(
-    "DetectKeyPhrasesResponseTypeDef", {"KeyPhrases": List[KeyPhraseTypeDef]}, total=False
+    "DetectKeyPhrasesResponseTypeDef", {"KeyPhrases": List["KeyPhraseTypeDef"]}, total=False
 )
 
 DetectSentimentResponseTypeDef = TypedDict(
     "DetectSentimentResponseTypeDef",
     {
         "Sentiment": Literal["POSITIVE", "NEGATIVE", "NEUTRAL", "MIXED"],
-        "SentimentScore": SentimentScoreTypeDef,
+        "SentimentScore": "SentimentScoreTypeDef",
     },
     total=False,
 )
 
 DetectSyntaxResponseTypeDef = TypedDict(
-    "DetectSyntaxResponseTypeDef", {"SyntaxTokens": List[SyntaxTokenTypeDef]}, total=False
+    "DetectSyntaxResponseTypeDef", {"SyntaxTokens": List["SyntaxTokenTypeDef"]}, total=False
 )
 
 DocumentClassificationJobFilterTypeDef = TypedDict(
@@ -798,7 +806,9 @@ KeyPhrasesDetectionJobFilterTypeDef = TypedDict(
 ListDocumentClassificationJobsResponseTypeDef = TypedDict(
     "ListDocumentClassificationJobsResponseTypeDef",
     {
-        "DocumentClassificationJobPropertiesList": List[DocumentClassificationJobPropertiesTypeDef],
+        "DocumentClassificationJobPropertiesList": List[
+            "DocumentClassificationJobPropertiesTypeDef"
+        ],
         "NextToken": str,
     },
     total=False,
@@ -807,7 +817,7 @@ ListDocumentClassificationJobsResponseTypeDef = TypedDict(
 ListDocumentClassifiersResponseTypeDef = TypedDict(
     "ListDocumentClassifiersResponseTypeDef",
     {
-        "DocumentClassifierPropertiesList": List[DocumentClassifierPropertiesTypeDef],
+        "DocumentClassifierPropertiesList": List["DocumentClassifierPropertiesTypeDef"],
         "NextToken": str,
     },
     total=False,
@@ -817,7 +827,7 @@ ListDominantLanguageDetectionJobsResponseTypeDef = TypedDict(
     "ListDominantLanguageDetectionJobsResponseTypeDef",
     {
         "DominantLanguageDetectionJobPropertiesList": List[
-            DominantLanguageDetectionJobPropertiesTypeDef
+            "DominantLanguageDetectionJobPropertiesTypeDef"
         ],
         "NextToken": str,
     },
@@ -826,14 +836,14 @@ ListDominantLanguageDetectionJobsResponseTypeDef = TypedDict(
 
 ListEndpointsResponseTypeDef = TypedDict(
     "ListEndpointsResponseTypeDef",
-    {"EndpointPropertiesList": List[EndpointPropertiesTypeDef], "NextToken": str},
+    {"EndpointPropertiesList": List["EndpointPropertiesTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListEntitiesDetectionJobsResponseTypeDef = TypedDict(
     "ListEntitiesDetectionJobsResponseTypeDef",
     {
-        "EntitiesDetectionJobPropertiesList": List[EntitiesDetectionJobPropertiesTypeDef],
+        "EntitiesDetectionJobPropertiesList": List["EntitiesDetectionJobPropertiesTypeDef"],
         "NextToken": str,
     },
     total=False,
@@ -841,14 +851,14 @@ ListEntitiesDetectionJobsResponseTypeDef = TypedDict(
 
 ListEntityRecognizersResponseTypeDef = TypedDict(
     "ListEntityRecognizersResponseTypeDef",
-    {"EntityRecognizerPropertiesList": List[EntityRecognizerPropertiesTypeDef], "NextToken": str},
+    {"EntityRecognizerPropertiesList": List["EntityRecognizerPropertiesTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListKeyPhrasesDetectionJobsResponseTypeDef = TypedDict(
     "ListKeyPhrasesDetectionJobsResponseTypeDef",
     {
-        "KeyPhrasesDetectionJobPropertiesList": List[KeyPhrasesDetectionJobPropertiesTypeDef],
+        "KeyPhrasesDetectionJobPropertiesList": List["KeyPhrasesDetectionJobPropertiesTypeDef"],
         "NextToken": str,
     },
     total=False,
@@ -857,30 +867,22 @@ ListKeyPhrasesDetectionJobsResponseTypeDef = TypedDict(
 ListSentimentDetectionJobsResponseTypeDef = TypedDict(
     "ListSentimentDetectionJobsResponseTypeDef",
     {
-        "SentimentDetectionJobPropertiesList": List[SentimentDetectionJobPropertiesTypeDef],
+        "SentimentDetectionJobPropertiesList": List["SentimentDetectionJobPropertiesTypeDef"],
         "NextToken": str,
     },
     total=False,
 )
 
-_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
-_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"Value": str}, total=False)
-
-
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
-
-
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
-    {"ResourceArn": str, "Tags": List[TagTypeDef]},
+    {"ResourceArn": str, "Tags": List["TagTypeDef"]},
     total=False,
 )
 
 ListTopicsDetectionJobsResponseTypeDef = TypedDict(
     "ListTopicsDetectionJobsResponseTypeDef",
     {
-        "TopicsDetectionJobPropertiesList": List[TopicsDetectionJobPropertiesTypeDef],
+        "TopicsDetectionJobPropertiesList": List["TopicsDetectionJobPropertiesTypeDef"],
         "NextToken": str,
     },
     total=False,
